(comment "CPSA 2.0.3")
(comment "All input read")

(defprotocol epmo_acctnum basic
  (defrole bank
    (vars (b c m name) (acctnum text) (hash name) (nc nm nb price text))
    (trace (recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (annotations b
      (1
        (forall ((pm name))
          (implies
            (and (authtransfer c acctnum b price pm nm)
              (reqtransfer pm b price pm nm))
            (dotransfer acctnum b price pm nm))))
      (2
        (and (says c (authtransfer c acctnum b price m nm))
          (says m (reqtransfer m b price m nm))))))
  (defrole customer
    (vars (b c m hash name) (acctnum nb nc nm goods price text))
    (trace (send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    (non-orig (privk b) (privk hash))
    (uniq-orig nc)
    (annotations c
      (1
        (says m
          (implies
            (exists ((acctnum2 text))
              (dotransfer acctnum2 b price m nm)) (doship m goods c))))
      (3
        (says b
          (forall ((pm name))
            (implies
              (and (authtransfer c acctnum b price m nm)
                (reqtransfer pm b price pm nm))
              (dotransfer acctnum b price pm nm)))))
      (4 (authtransfer c acctnum b price m nm))))
  (defrole merchant
    (vars (b c m hash name) (nb nc nm goods price text))
    (trace (recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (uniq-orig nm)
    (annotations m
      (1
        (implies
          (exists ((acctnum2 text)) (dotransfer acctnum2 b price m nm))
          (doship m goods c)))
      (2
        (and
          (says b
            (forall ((pm name))
              (exists ((acctnum2 text))
                (implies
                  (and (authtransfer c acctnum2 b price m nm)
                    (reqtransfer pm b price pm nm))
                  (dotransfer acctnum2 b price pm nm)))))
          (says c
            (exists ((acctnum2 text))
              (authtransfer c acctnum2 b price m nm)))))
      (3 (and (reqtransfer m b price m nm) (doship m goods c))))))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price text) (b m c hash name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 0)
  (unrealized (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum text) (b m c hash name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (precedes ((0 1) (1 0)) ((1 1) (0 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b)) (0 2))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))))
  (label 1)
  (parent 0)
  (unrealized (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 text)
    (b m c hash b-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (1 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b-0)))))
  (label 2)
  (parent 1)
  (seen 5 7)
  (unrealized (0 0) (0 2) (1 0))
  (comment "7 in cohort - 4 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 text)
    (b m c hash b-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (1 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0)))))
  (label 3)
  (parent 1)
  (seen 7)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) price
    (1 0) (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))))
  (label 4)
  (parent 2)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (1 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 5)
  (parent 2)
  (seen 12)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (1 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 6)
  (parent 2)
  (seen 13)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (1 0)
    (enc nc price m price (pubk c))
    (enc c nc price acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b-0))))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 7)
  (parent 2)
  (seen 14)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc nc nm m price (pubk c))
    (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 8)
  (parent 3)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand bank 2) nm (1 0)
    (enc nc nm m price (pubk c))
    (enc c nc nm acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 9)
  (parent 3)
  (seen 14)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))))
  (label 10)
  (parent 4)
  (seen 18)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 11)
  (parent 4)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 12)
  (parent 5)
  (seen 21)
  (unrealized (0 0) (0 2) (1 0))
  (comment "9 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 13)
  (parent 6)
  (seen 12 23)
  (unrealized (0 0) (0 2) (1 0))
  (comment "7 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b-0))))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 14)
  (parent 7)
  (seen 12 23)
  (unrealized (0 0) (0 2) (1 0))
  (comment "7 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 15)
  (parent 8)
  (seen 25)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nm-0 price-0 text)
    (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 16)
  (parent 8)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (3 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 17)
  (parent 9)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb price price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 18)
  (parent 10)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nm price-0 text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 19)
  (parent 11)
  (seen 29)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) price (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 20)
  (parent 12)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 5) price (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price))))
  (label 21)
  (parent 12)
  (unrealized (0 0) (0 2) (1 0) (3 3))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) price (1 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 22)
  (parent 13)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (3 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (1 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 23)
  (parent 13)
  (seen 12)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) price
    (1 0) (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 24)
  (parent 14)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 25)
  (parent 15)
  (unrealized)
  (shape))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nm-0 price-0 text)
    (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 26)
  (parent 16)
  (seen 37)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 27)
  (parent 17)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods price-0 text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb price price-0)
  (operation generalization separated price-0)
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price-0 (pubk hash)) (privk m))))
    ((recv (enc c nc price-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price-0 m price (pubk c)))
      (send (enc c nc price-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          nb))))
  (label 28)
  (parent 18)
  (seen 25)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nm price-0 acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb price price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 29)
  (parent 19)
  (seen 18)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 30)
  (parent 20)
  (seen 40)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 31)
  (parent 20)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc price price price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 32)
  (parent 21)
  (seen 42)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 33)
  (parent 22)
  (seen 43)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 34)
  (parent 22)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 35)
  (parent 24)
  (seen 45)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 36)
  (parent 24)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nm-0 price-0 acctnum goods text)
    (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 37)
  (parent 26)
  (seen 25)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 38)
  (parent 27)
  (seen 47)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nb-0 nm-0 price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 39)
  (parent 27)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price acctnum) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum acctnum (pubk hash))
    (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum acctnum (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 40)
  (parent 30)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nm price-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 41)
  (parent 31)
  (seen 50)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (4 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 42)
  (parent 32)
  (seen 52 53)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "7 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb nb-0 acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price acctnum) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum acctnum (pubk hash))
    (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum acctnum (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 43)
  (parent 33)
  (seen 49)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum price) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 44)
  (parent 34)
  (seen 54)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb price price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 45)
  (parent 35)
  (seen 18)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 46)
  (parent 36)
  (seen 55)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nb-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 47)
  (parent 38)
  (seen 25)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nb-0 nm-0 price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 48)
  (parent 39)
  (seen 56)
  (unrealized (0 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation generalization deleted (2 0))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 49)
  (parent 40)
  (seen 18)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb nm price acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price acctnum) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum acctnum (pubk hash))
    (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum acctnum (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 50)
  (parent 41)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 4) (1 0)) ((3 1) (2 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (acctnum-0 price)) price (4 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 51)
  (parent 42)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (4 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 52)
  (parent 42)
  (seen 61)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (4 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 53)
  (parent 42)
  (seen 62)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb nb-0 nm price acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price acctnum) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum acctnum (pubk hash))
    (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum acctnum (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 54)
  (parent 44)
  (seen 57)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nm price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb price price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 55)
  (parent 46)
  (seen 29)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nb-0 nm-0 price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 56)
  (parent 48)
  (seen 37)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb nm price acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price acctnum) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price acctnum) (b b) (c c) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price acctnum) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation generalization deleted (2 0))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m acctnum (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum acctnum (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m acctnum (pubk c)))
      (send (enc c nc acctnum acctnum acctnum (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum acctnum (pubk hash))
            (privk b)) nb))))
  (label 57)
  (parent 50)
  (seen 49)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 4) (1 0)) ((3 1) (2 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 58)
  (parent 51)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (3 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 59)
  (parent 51)
  (seen 65)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (4 0))
    ((2 2) (3 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 60)
  (parent 51)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (5 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 61)
  (parent 52)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (5 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 62)
  (parent 53)
  (seen 61 70)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "7 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 4) (1 0)) ((3 1) (2 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 63)
  (parent 58)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 64)
  (parent 58)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (4 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 65)
  (parent 59)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (4 0))
    ((2 2) (3 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 66)
  (parent 60)
  (seen 63 64)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 0) (4 0)) ((2 2) (3 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 67)
  (parent 60)
  (seen 73)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (acctnum-0 price)) price (4 0)
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 68)
  (parent 61)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (acctnum-0 price)) price (4 0)
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 69)
  (parent 62)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 acctnum-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) price (4 0)
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-2))
            (privk b-0)) (enc nc price (pubk c))))))
  (label 70)
  (parent 62)
  (seen 61)
  (unrealized (0 0) (0 2) (1 0) (4 0) (6 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nm price-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 71)
  (parent 64)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b)) (enc nc goods-0 (pubk c))))))
  (label 72)
  (parent 65)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (3 0)) ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b-0)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 73)
  (parent 65)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c))))))
  (label 74)
  (parent 68)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 75)
  (parent 68)
  (seen 85)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 76)
  (parent 68)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc nb-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 77)
  (parent 69)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc nb-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 78)
  (parent 69)
  (seen 90)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc nb-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 79)
  (parent 69)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-1))
            (privk b)) (enc nc goods (pubk c))))))
  (label 80)
  (parent 72)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 81)
  (parent 72)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (3 0)) ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-1))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 82)
  (parent 73)
  (seen 80 81)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c))))))
  (label 83)
  (parent 74)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 84)
  (parent 74)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (5 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 85)
  (parent 75)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 86)
  (parent 76)
  (seen 83 84)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 0) (5 0)) ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 87)
  (parent 76)
  (seen 96)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 88)
  (parent 77)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 89)
  (parent 77)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (added-strand customer 3) price (5 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 90)
  (parent 78)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc nb-0 (pubk c))
    (enc nc price m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 91)
  (parent 79)
  (seen 88 89)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 0) (5 0)) ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc nb-0 (pubk c))
    (enc nc price m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c))))))
  (label 92)
  (parent 79)
  (seen 99)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-1))
            (privk b)) (enc nc goods (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 93)
  (parent 81)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 94)
  (parent 84)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c))))))
  (label 95)
  (parent 85)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (6 0))
    ((2 2) (4 0)) ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 96)
  (parent 85)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 97)
  (parent 89)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc nb-0 (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c))))))
  (label 98)
  (parent 90)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (6 0))
    ((2 2) (4 0)) ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc nb-0 (pubk c)) (enc nc price m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) price)))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b-0)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b-0)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 99)
  (parent 90)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods text) (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-2))
            (privk b)) (enc nc goods (pubk c))))))
  (label 100)
  (parent 95)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (6 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 101)
  (parent 95)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (6 0))
    ((2 2) (4 0)) ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc price price price (pubk hash-1))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc price m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 102)
  (parent 96)
  (seen 100 101)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-2))
            (privk b)) (enc nc goods (pubk c))))))
  (label 103)
  (parent 98)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (6 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 104)
  (parent 98)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods-0)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (6 0))
    ((2 2) (4 0)) ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3))
    ((4 1) (3 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (b-0 b) (acctnum price)) nc (1 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc "hash" c nc goods-0 price price (pubk hash-2))
    (enc "hash" c nc nb-0 price price (pubk hash-1))
    (enc nc price (pubk c)) (enc nc goods-0 (pubk c))
    (enc nc nb-0 (pubk c)) (enc nc price m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods-0 price price (pubk hash-2))
            (privk b)) (enc nc goods-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 105)
  (parent 99)
  (seen 103 104)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (6 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-2))
            (privk b)) (enc nc goods (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 106)
  (parent 101)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nm price-0 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum price) (nb price) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb goods)
    (price price) (b b) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (6 0)) ((2 2) (4 0))
    ((2 2) (5 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb price nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) price)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc goods price price (pubk hash-2))
            (privk b)) (enc nc goods (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 107)
  (parent 104)
  (unrealized (0 2))
  (comment "empty cohort"))

(comment "Nothing left to do")

(defprotocol epmo_acctnum basic
  (defrole bank
    (vars (b c m name) (acctnum text) (hash name) (nc nm nb price text))
    (trace (recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (annotations b
      (1
        (forall ((pm name))
          (implies
            (and (authtransfer c acctnum b price pm nm)
              (reqtransfer pm b price pm nm))
            (dotransfer acctnum b price pm nm))))
      (2
        (and (says c (authtransfer c acctnum b price m nm))
          (says m (reqtransfer m b price m nm))))))
  (defrole customer
    (vars (b c m hash name) (acctnum nb nc nm goods price text))
    (trace (send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    (non-orig (privk b) (privk hash))
    (uniq-orig nc)
    (annotations c
      (1
        (says m
          (implies
            (exists ((acctnum2 text))
              (dotransfer acctnum2 b price m nm)) (doship m goods c))))
      (3
        (says b
          (forall ((pm name))
            (implies
              (and (authtransfer c acctnum b price m nm)
                (reqtransfer pm b price pm nm))
              (dotransfer acctnum b price pm nm)))))
      (4 (authtransfer c acctnum b price m nm))))
  (defrole merchant
    (vars (b c m hash name) (nb nc nm goods price text))
    (trace (recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (uniq-orig nm)
    (annotations m
      (1
        (implies
          (exists ((acctnum2 text)) (dotransfer acctnum2 b price m nm))
          (doship m goods c)))
      (2
        (and
          (says b
            (forall ((pm name))
              (exists ((acctnum2 text))
                (implies
                  (and (authtransfer c acctnum2 b price m nm)
                    (reqtransfer pm b price pm nm))
                  (dotransfer acctnum2 b price pm nm)))))
          (says c
            (exists ((acctnum2 text))
              (authtransfer c acctnum2 b price m nm)))))
      (3 (and (reqtransfer m b price m nm) (doship m goods c))))))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 108)
  (unrealized (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price nc-0 goods price-0 text)
    (b m c hash c-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc-0) (nm nm) (goods goods)
    (price price-0) (b b) (c c-0) (m m) (hash hash))
  (precedes ((0 1) (1 2)) ((1 1) (0 0)) ((1 3) (0 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation encryption-test (added-strand merchant 4)
    (enc (enc "hash" b m nb nm (pubk hash)) (privk m)) (0 2))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c-0 nc-0 goods (pubk m)))
      (send (enc nc-0 nm m price-0 (pubk c-0)))
      (recv
        (cat
          (enc (enc "hash" c-0 nc-0 nb nm price-0 (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 109)
  (parent 108)
  (unrealized (1 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (1 2)) ((1 1) (0 0)) ((1 3) (0 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b)) (1 2))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 110)
  (parent 109)
  (seen 111)
  (unrealized (0 0) (1 2))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price goods acctnum-0 goods-0 text)
    (b m c hash b-0 m-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m-0) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nm nb nc)
  (operation nonce-test (added-strand customer 5) nb (1 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods-0 (pubk m-0)))
      (recv (enc nc nm m-0 price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b-0))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b-0))
          nb))))
  (label 111)
  (parent 110)
  (unrealized (0 0) (2 1) (2 3))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price goods acctnum-0 goods-0 text)
    (b m c hash b-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nm nb nc)
  (operation nonce-test (contracted (m-0 m)) nm (2 1)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b-0))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b-0))
          nb))))
  (label 112)
  (parent 111)
  (unrealized (0 0) (1 0) (2 3))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price goods acctnum-0 goods-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b)) (2 3))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 113)
  (parent 112)
  (unrealized (0 0) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation nonce-test (contracted (goods-0 goods)) nc (1 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 114)
  (parent 113)
  (unrealized (0 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nm nb nc acctnum price goods acctnum-0 goods-0 nm-0 price-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 115)
  (parent 113)
  (unrealized (0 0) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand customer 3) price (0 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 116)
  (parent 114)
  (seen 120 122)
  (unrealized (0 0))
  (comment "7 in cohort - 4 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation nonce-test (added-strand customer 3) nm (0 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 117)
  (parent 114)
  (seen 122)
  (unrealized (0 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nm-0 price-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (0 0)) ((1 1) (2 1)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (1 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 118)
  (parent 115)
  (unrealized (0 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price acctnum goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price)
  (operation nonce-test (contracted (acctnum-0 acctnum)) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 119)
  (parent 116)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (3 0)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 120)
  (parent 116)
  (seen 128)
  (unrealized (0 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nb-0 text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (3 0)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 121)
  (parent 116)
  (seen 129)
  (unrealized (0 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (3 0)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price acctnum-0 price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 122)
  (parent 116)
  (seen 130)
  (unrealized (0 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc price acctnum goods text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc)
  (operation nonce-test (contracted (acctnum-0 acctnum)) nm (0 0)
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 123)
  (parent 117)
  (unrealized)
  (shape))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (3 0)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc)
  (operation nonce-test (added-strand bank 2) nm (0 0)
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum-0 price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc nm acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 124)
  (parent 117)
  (seen 130)
  (unrealized (0 0) (3 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods nm price-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand customer 3) price (0 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 125)
  (parent 118)
  (seen 133 135)
  (unrealized (0 0))
  (comment "7 in cohort - 4 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nm-0 price-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (added-strand customer 3) nm (0 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 126)
  (parent 118)
  (seen 135)
  (unrealized (0 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price acctnum goods price-0 text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price-0) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price price-0)
  (operation generalization separated price-0)
  (traces
    ((recv (enc c nc price-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price-0 (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price-0 (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price-0 m price (pubk c)))
      (send (enc c nc price-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price-0 price (pubk hash)) (privk b))
          nb))))
  (label 127)
  (parent 119)
  (seen 123)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 128)
  (parent 120)
  (unrealized (0 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nb-0 text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 129)
  (parent 121)
  (seen 128 140)
  (unrealized (0 0))
  (comment "7 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand customer 3) price (3 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 130)
  (parent 122)
  (seen 128 140)
  (unrealized (0 0))
  (comment "7 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc)
  (operation nonce-test (added-strand customer 3) nm (3 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc nm acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 131)
  (parent 124)
  (unrealized (0 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price acctnum goods nm price-0 text) (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price nm)
  (operation nonce-test (contracted (acctnum-0 acctnum)) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 132)
  (parent 125)
  (seen 119)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nm price-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (4 0)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0))
    ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 133)
  (parent 125)
  (seen 143)
  (unrealized (0 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (4 0)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0))
    ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 134)
  (parent 125)
  (seen 144)
  (unrealized (0 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (4 0)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0))
    ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc nc price m price (pubk c))
    (enc c nc price acctnum-0 price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 135)
  (parent 125)
  (seen 145)
  (unrealized (0 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc price acctnum goods nm-0 price-0 text)
    (b m c hash name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (contracted (acctnum-0 acctnum)) nm (0 0)
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 136)
  (parent 126)
  (seen 123)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nm-0 price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (4 0)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 2) (0 0)) ((2 4) (1 2)) ((3 1) (1 0))
    ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (added-strand bank 2) nm (0 0)
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum-0 price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((recv (enc c nc nm acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 137)
  (parent 126)
  (seen 145)
  (unrealized (0 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price goods text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (contracted (acctnum price)) price (0 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 138)
  (parent 128)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price goods nb-0 text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (contracted (acctnum price)) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 139)
  (parent 129)
  (seen 147)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nb-0 text)
    (b m c hash hash-0 hash-1 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (4 0)) ((1 3) (0 2))
    ((2 0) (1 0)) ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0))
    ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nc price)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c))))))
  (label 140)
  (parent 129)
  (seen 128)
  (unrealized (0 0) (4 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price acctnum goods nb-0 text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price)
  (operation nonce-test (contracted (acctnum-0 acctnum)) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 141)
  (parent 130)
  (seen 119)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc price acctnum goods nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (3 0)) ((2 4) (1 2)) ((3 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc)
  (operation nonce-test (contracted (acctnum-0 acctnum)) nm (0 0)
    (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 142)
  (parent 131)
  (seen 123)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nm price-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand customer 3) price (4 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 143)
  (parent 133)
  (unrealized (0 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand customer 3) price (4 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 144)
  (parent 134)
  (seen 143 150)
  (unrealized (0 0))
  (comment "7 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price acctnum-0 goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand customer 3) price (4 0)
    (enc nc price m price (pubk c)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 145)
  (parent 135)
  (seen 143 150)
  (unrealized (0 0))
  (comment "7 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc acctnum price acctnum-0 goods nm-0 price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (added-strand customer 3) nm (4 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((recv (enc c nc nm acctnum-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 146)
  (parent 137)
  (unrealized (0 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price goods text) (b m c hash name))
  (defstrand bank 3 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (1 0))
    ((2 2) (0 0)) ((2 4) (1 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nb nc price)
  (operation generalization deleted (3 0))
  (traces
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))))
  (label 147)
  (parent 138)
  (seen 119)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price goods nm price-0 text) (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (contracted (acctnum price)) price (0 0)
    (enc "hash" c nc price price price (pubk hash-0))
    (enc nc price (pubk c)) (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-0))
            (privk b)) (enc nc price (pubk c))))))
  (label 148)
  (parent 143)
  (seen 138)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum price) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (contracted (acctnum price)) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 149)
  (parent 144)
  (seen 139)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc acctnum price goods nm price-0 nb-0 text)
    (b m c hash hash-0 hash-1 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum price) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum price) (nc nc) (nm price) (nb price)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 1) (5 0)) ((1 3) (0 2))
    ((2 0) (3 0)) ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nc price nm)
  (operation nonce-test (added-strand bank 2) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price price price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price price price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc price price price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc price price price (pubk hash-1))
            (privk b)) (enc nc price (pubk c))))))
  (label 150)
  (parent 144)
  (seen 143)
  (unrealized (0 0) (5 0))
  (comment "2 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb nc price acctnum goods nm price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm price) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm price) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm price)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm price) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nb nc price nm)
  (operation nonce-test (contracted (acctnum-0 acctnum)) price (0 0)
    (enc "hash" c nc nb-0 price price (pubk hash-0))
    (enc nc price m price (pubk c))
    (enc c nc price acctnum price (pubk b)))
  (traces
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc price m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb price (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc price m price (pubk c)))
      (send (enc c nc price acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb price price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc price acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 price price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 151)
  (parent 145)
  (seen 141)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nb nc price acctnum goods nm-0 price-0 nb-0 text)
    (b m c hash hash-0 name))
  (defstrand bank 3 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 3)) ((1 1) (2 1)) ((1 3) (0 2)) ((2 0) (3 0))
    ((2 2) (4 0)) ((2 4) (1 2)) ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk hash-0))
  (uniq-orig nm nb nc nm-0)
  (operation nonce-test (contracted (acctnum-0 acctnum)) nm (0 0)
    (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 152)
  (parent 146)
  (seen 142)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(comment "Nothing left to do")
